package com.huangge1199.controller;
import com.huangge1199.base.R;
import com.huangge1199.domain.UserTabComments;
import com.huangge1199.service.IDatabaseService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * DatabaseController
 *
 * @author huangge1199
 * @since 2025/3/12 10:16:42
 */
@Api("数据库可视化")
@RestController
@RequestMapping("/database")
public class DatabaseController{

    @Resource
    private IDatabaseService databaseService;

    @ApiOperation("获取数据库所有表名称")
    @GetMapping("/listAllTable")
    public
    R<List<UserTabComments>> listAllTable()
    {
        List<UserTabComments> tableList = databaseService.listAllTable();
        return R.ok(tableList);
    }

    @ApiOperation("根据表名获取表中所有字段")
    @GetMapping("/listColByTable")
    public
    R<List<UserTabComments>> listColByTable(String tableName)
    {
        List<UserTabComments> tableList = databaseService.listColByTable(tableName);
        return R.ok(tableList);
    }

    @ApiOperation("根据SQL进行查询")
    @GetMapping("/executeQuery")
    public
    R<List<Map<String,String>>> getQuery(String sql)
    {
        List<Map<String,String>> resultList = databaseService.executeQuery(sql);
        return R.ok(resultList);
    }

    @ApiOperation("根据表达式计算结果")
    @PostMapping("/evaluate")
    public R<Double> evaluate(@RequestBody String expression)
    {
        double result = 0;
        try {
            result = databaseService.evaluate(expression);
        } catch (Exception e) {
            return R.fail(e.getMessage());
        }
        return R.ok(result);
    }
}
